==> ui-framework-4.14.2-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractWidgetTypeTemplate.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractWidgetTypeTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _8_1_0785676994 _8_1_0785676994;
	public WidgetTypeTemplate._8_1_0785676994. _9_2_1887123514 _9_2_1887123514;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _10_3_1557722831 _10_3_1557722831;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _11_3_1646393896 _11_3_1646393896;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. Links links;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _14_4_0484003806 _14_4_0484003806;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _15_4_0881274725 _15_4_0881274725;
	public _17_1_01547850907 _17_1_01547850907;
	public WidgetMold widget;

    public AbstractWidgetTypeTemplate(B box) {
        super(box);
        id("widgetTypeTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_8_1_0785676994 == null) _8_1_0785676994 = register(new _8_1_0785676994(box()).<_8_1_0785676994>id("a_1901160497").owner(AbstractWidgetTypeTemplate.this));
		if (_8_1_0785676994 != null) _9_2_1887123514 = _8_1_0785676994._9_2_1887123514;
		if (_9_2_1887123514 != null) _10_3_1557722831 = _8_1_0785676994._9_2_1887123514._10_3_1557722831;
		if (_9_2_1887123514 != null) _11_3_1646393896 = _8_1_0785676994._9_2_1887123514._11_3_1646393896;
		if (_9_2_1887123514 != null) links = _8_1_0785676994._9_2_1887123514.links;
		if (links != null) _14_4_0484003806 = _8_1_0785676994._9_2_1887123514.links._14_4_0484003806;
		if (links != null) _15_4_0881274725 = _8_1_0785676994._9_2_1887123514.links._15_4_0881274725;
		if (_17_1_01547850907 == null) _17_1_01547850907 = register(new _17_1_01547850907(box()).<_17_1_01547850907>id("a_13197196").owner(AbstractWidgetTypeTemplate.this));
		if (_17_1_01547850907 != null) widget = _17_1_01547850907.widget;
	}

	public class _8_1_0785676994 extends io.intino.alexandria.ui.displays.components.Header<io.intino.alexandria.ui.displays.notifiers.HeaderNotifier, B>  {
		public WidgetTypeTemplate._8_1_0785676994. _9_2_1887123514 _9_2_1887123514;

		public _8_1_0785676994(B box) {
			super(box);

			_color("white");
		}

		@Override
		public void init() {
			super.init();
			if (_9_2_1887123514 == null) _9_2_1887123514 = register(new _9_2_1887123514(box()).<_9_2_1887123514>id("a309771464").owner(AbstractWidgetTypeTemplate.this));
		}

		public class _9_2_1887123514 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _10_3_1557722831 _10_3_1557722831;
			public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _11_3_1646393896 _11_3_1646393896;
			public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. Links links;

			public _9_2_1887123514(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_10_3_1557722831 == null) _10_3_1557722831 = register(new _10_3_1557722831(box()).<_10_3_1557722831>id("a149265222").owner(AbstractWidgetTypeTemplate.this));
				if (_11_3_1646393896 == null) _11_3_1646393896 = register(new _11_3_1646393896(box()).<_11_3_1646393896>id("a_607116561").owner(AbstractWidgetTypeTemplate.this));
				if (links == null) links = register(new Links(box()).<Links>id("a790298661").owner(AbstractWidgetTypeTemplate.this));
			}

			public class _10_3_1557722831 extends io.intino.alexandria.ui.displays.components.Image<io.intino.alexandria.ui.displays.notifiers.ImageNotifier, B>  {

				public _10_3_1557722831(B box) {
					super(box);
					_value(AbstractWidgetTypeTemplate.class.getResource("/images/intino.png"));
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _11_3_1646393896 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _11_3_1646393896(B box) {
					super(box);
					_value("intino");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class Links extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _14_4_0484003806 _14_4_0484003806;
				public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _15_4_0881274725 _15_4_0881274725;

				public Links(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_14_4_0484003806 == null) _14_4_0484003806 = register(new _14_4_0484003806(box()).<_14_4_0484003806>id("a_1216630451").owner(AbstractWidgetTypeTemplate.this));
					if (_15_4_0881274725 == null) _15_4_0881274725 = register(new _15_4_0881274725(box()).<_15_4_0881274725>id("a1334135757").owner(AbstractWidgetTypeTemplate.this));
				}

				public class _14_4_0484003806 extends io.intino.alexandria.ui.displays.components.OpenSite<io.intino.alexandria.ui.displays.notifiers.OpenSiteNotifier, B>  {

					public _14_4_0484003806(B box) {
						super(box);
						_title("home");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_site("https://www.intino.io");
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class _15_4_0881274725 extends io.intino.alexandria.ui.displays.components.OpenPage<io.intino.alexandria.ui.displays.notifiers.OpenPageNotifier, B>  {

					public _15_4_0881274725(B box) {
						super(box);
						_title("widgets");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_path("/widgets");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}
		}
	}

	public class _17_1_01547850907 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public WidgetMold widget;

		public _17_1_01547850907(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (widget == null) widget = register(new WidgetMold((UiFrameworkBox)box()).id("a_818492150"));
		}
	}
}

==> ui-framework-4.15.0-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractWidgetTypeTemplate.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractWidgetTypeTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _8_1_0785676994 _8_1_0785676994;
	public WidgetTypeTemplate._8_1_0785676994. _9_2_1887123514 _9_2_1887123514;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _10_3_1557722831 _10_3_1557722831;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _11_3_1646393896 _11_3_1646393896;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. Links links;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _14_4_0484003806 _14_4_0484003806;
	public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _15_4_0881274725 _15_4_0881274725;
	public _17_1_01547850907 _17_1_01547850907;
	public WidgetMold widget;

    public AbstractWidgetTypeTemplate(B box) {
        super(box);
        id("widgetTypeTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (_8_1_0785676994 == null) _8_1_0785676994 = register(new _8_1_0785676994(box()).<_8_1_0785676994>id("a_1901160497").owner(AbstractWidgetTypeTemplate.this));
		if (_8_1_0785676994 != null) _9_2_1887123514 = _8_1_0785676994._9_2_1887123514;
		if (_9_2_1887123514 != null) _10_3_1557722831 = _8_1_0785676994._9_2_1887123514._10_3_1557722831;
		if (_9_2_1887123514 != null) _11_3_1646393896 = _8_1_0785676994._9_2_1887123514._11_3_1646393896;
		if (_9_2_1887123514 != null) links = _8_1_0785676994._9_2_1887123514.links;
		if (links != null) _14_4_0484003806 = _8_1_0785676994._9_2_1887123514.links._14_4_0484003806;
		if (links != null) _15_4_0881274725 = _8_1_0785676994._9_2_1887123514.links._15_4_0881274725;
		if (_17_1_01547850907 == null) _17_1_01547850907 = register(new _17_1_01547850907(box()).<_17_1_01547850907>id("a_13197196").owner(AbstractWidgetTypeTemplate.this));
		if (_17_1_01547850907 != null) widget = _17_1_01547850907.widget;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_8_1_0785676994 != null) _8_1_0785676994.unregister();
	    if (_17_1_01547850907 != null) _17_1_01547850907.unregister();
	}

	public class _8_1_0785676994 extends io.intino.alexandria.ui.displays.components.Header<io.intino.alexandria.ui.displays.notifiers.HeaderNotifier, B>  {
		public WidgetTypeTemplate._8_1_0785676994. _9_2_1887123514 _9_2_1887123514;

		public _8_1_0785676994(B box) {
			super(box);

			_color("white");
		}

		@Override
		public void init() {
			super.init();
			if (_9_2_1887123514 == null) _9_2_1887123514 = register(new _9_2_1887123514(box()).<_9_2_1887123514>id("a309771464").owner(AbstractWidgetTypeTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_9_2_1887123514 != null) _9_2_1887123514.unregister();
		}

		public class _9_2_1887123514 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _10_3_1557722831 _10_3_1557722831;
			public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. _11_3_1646393896 _11_3_1646393896;
			public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514. Links links;

			public _9_2_1887123514(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_10_3_1557722831 == null) _10_3_1557722831 = register(new _10_3_1557722831(box()).<_10_3_1557722831>id("a149265222").owner(AbstractWidgetTypeTemplate.this));
				if (_11_3_1646393896 == null) _11_3_1646393896 = register(new _11_3_1646393896(box()).<_11_3_1646393896>id("a_607116561").owner(AbstractWidgetTypeTemplate.this));
				if (links == null) links = register(new Links(box()).<Links>id("a790298661").owner(AbstractWidgetTypeTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_10_3_1557722831 != null) _10_3_1557722831.unregister();
				if (_11_3_1646393896 != null) _11_3_1646393896.unregister();
				if (links != null) links.unregister();
			}

			public class _10_3_1557722831 extends io.intino.alexandria.ui.displays.components.Image<io.intino.alexandria.ui.displays.notifiers.ImageNotifier, B>  {

				public _10_3_1557722831(B box) {
					super(box);
					_value(AbstractWidgetTypeTemplate.class.getResource("/images/intino.png"));
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class _11_3_1646393896 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _11_3_1646393896(B box) {
					super(box);
					_value("intino");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class Links extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _14_4_0484003806 _14_4_0484003806;
				public WidgetTypeTemplate._8_1_0785676994._9_2_1887123514.Links. _15_4_0881274725 _15_4_0881274725;

				public Links(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_14_4_0484003806 == null) _14_4_0484003806 = register(new _14_4_0484003806(box()).<_14_4_0484003806>id("a_1216630451").owner(AbstractWidgetTypeTemplate.this));
					if (_15_4_0881274725 == null) _15_4_0881274725 = register(new _15_4_0881274725(box()).<_15_4_0881274725>id("a1334135757").owner(AbstractWidgetTypeTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_14_4_0484003806 != null) _14_4_0484003806.unregister();
					if (_15_4_0881274725 != null) _15_4_0881274725.unregister();
				}

				public class _14_4_0484003806 extends io.intino.alexandria.ui.displays.components.OpenSite<io.intino.alexandria.ui.displays.notifiers.OpenSiteNotifier, B>  {

					public _14_4_0484003806(B box) {
						super(box);
						_title("home");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_site("https://www.intino.io");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class _15_4_0881274725 extends io.intino.alexandria.ui.displays.components.OpenPage<io.intino.alexandria.ui.displays.notifiers.OpenPageNotifier, B>  {

					public _15_4_0881274725(B box) {
						super(box);
						_title("widgets");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
						_path("/widgets");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}
		}
	}

	public class _17_1_01547850907 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public WidgetMold widget;

		public _17_1_01547850907(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (widget == null) widget = register(new WidgetMold((UiFrameworkBox)box()).id("a_818492150"));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (widget != null) widget.unregister();
		}
	}
}
